@@ -1,27 +1,35 @@
 """This modules contains the JSON Class types marker."""
 from __future__ import annotations
-from typing import Callable, Any, Optional, Literal
+from typing import Callable, Any, Optional, Union, Literal
 from copy import deepcopy
-from .fields import FieldDescription
+from .field_definition import FieldDefinition
 from .validators import (UseForValidator, BoolValidator, ChainedValidator,
-                         DateValidator, DatetimeValidator, DefaultValidator,
-                         DictOfValidator, EagerValidator, EmbeddedValidator,
-                         FloatValidator, IndexValidator, InstanceOfValidator,
+                         CompareValidator, DateValidator, DatetimeValidator,
+                         DefaultValidator, DictOfValidator, EagerValidator,
+                         EmbeddedValidator, EnumValidator,
+                         FloatValidator, IndexValidator, InputAllValidator,
+                         InputNameValidator, InputLnameValidator,
+                         InputValueValidator, InstanceOfValidator,
                          IntValidator, InvalidValidator, LengthValidator,
                          LinkedByValidator, LinkedInValidator,
                          LinkedThruValidator, LinkToValidator, ListOfValidator,
                          MatchValidator, MaxValidator, MaxlengthValidator,
                          MinValidator, MinlengthValidator, NegativeValidator,
                          NonnullValidator, NullableValidator, OneOfValidator,
-                         OneOfTypeValidator, PositiveValidator,
-                         PresentValidator, PrimaryValidator, RangeValidator,
-                         ReadonlyValidator, ReadwriteValidator,
+                         OneOfTypeValidator, OnWriteValidator, OnSaveValidator,
+                         OnUpdateValidator, OutputLnameValidator,
+                         OutputNameValidator, OutputValueValidator,
+                         PositiveValidator, PresentValidator,
+                         PresentWithValidator, PresentWithoutValidator,
+                         PreserializeValidator, PrimaryValidator,
+                         RangeValidator, ReadonlyValidator, ReadwriteValidator,
                          RefereeValidator, ReferrerValidator,
-                         RequiredValidator, SetOnSaveValidator, ShapeValidator,
-                         StrValidator, StrictValidator, TransformValidator,
-                         TrimValidator, TruncateValidator, UniqueValidator,
-                         ValidateValidator, Validator, WriteNonnullValidator,
-                         WriteonceValidator, WriteonlyValidator)
+                         RequiredValidator, ResetValidator, SetOnSaveValidator,
+                         ShapeValidator, StrValidator, StrictValidator,
+                         TempValidator, TransformValidator, TrimValidator,
+                         TruncateValidator, UniqueValidator, ValidateValidator,
+                         Validator, WriteNonnullValidator, WriteonceValidator,
+                         WriteonlyValidator)
 
 Str = str
 Int = int
@@ -40,14 +48,14 @@ class Types:
         *args: Validator
     ) -> None:
         if not original:
-            self.fdesc = FieldDescription()
+            self.definition = FieldDefinition()
             self.validator = ChainedValidator()
         else:
-            self.fdesc = deepcopy(original.fdesc)
+            self.definition = deepcopy(original.definition)
             validator = original.validator
             for arg in args:
                 validator = validator.append(arg)
-                arg.define(self.fdesc)
+                arg.define(self.definition)
             self.validator = validator
 
     @property
@@ -82,8 +90,8 @@ class Types:
     def readonly(self) -> Types:
         """Fields marked with readonly will not be able to go through
         initialization and set method. You can update value of these fields
-        directly or through update method. This prevents client side to post data
-        directly into these fields.
+        directly or through update method. This prevents client side to post
+        data directly into these fields.
 
         `writeonce`, `readonly` and `writenonnull` cannot be presented
         together.
@@ -92,24 +100,25 @@ class Types:
 
     @property
     def writeonly(self) -> Types:
-        """Fields marked with writeonly will not be available in outgoing json form.
-        Users' password is a great example of writeonly.
+        """Fields marked with writeonly will not be available in outgoing json
+        form. Users' password is a great example of writeonly.
         """
         return Types(self, WriteonlyValidator())
 
     @property
     def readwrite(self) -> Types:
-        """Fields marked with readwrite will be presented in both inputs and outputs.
-        This is the default behavior. And this specifier can be omitted.
+        """Fields marked with readwrite will be presented in both inputs and
+        outputs. This is the default behavior. And this specifier can be
+        omitted.
         """
         return Types(self, ReadwriteValidator())
 
     @property
     def writeonce(self) -> Types:
-        """Fields marked with writeonce can only be set once through initialization
-        and set method. You can update value of these fields directly or through
-        update method. This is suitable for e.g. dating app user gender. Gender
-        should not be changed once set.
+        """Fields marked with writeonce can only be set once through
+        initialization and set method. You can update value of these fields
+        directly or through update method. This is suitable for e.g. dating app
+        user gender. Gender should not be changed once set.
 
         `writeonce`, `readonly` and `writenonnull` cannot be presented
         together.
@@ -135,6 +144,15 @@ class Types:
         """
         return Types(self, ReadonlyValidator(), WriteonlyValidator())
 
+    @property
+    def temp(self) -> Types:
+        """Fields marked with temp won't be written into database. As soon as
+        database writing happens, value of this field is cleared and set to
+        None. Examples of it's use cases are authentication code validation,
+        input validation, etc.
+        """
+        return Types(self, TempValidator())
+
     @property
     def index(self) -> Types:
         """Fields marked with index are picked up by ORM integrations to setup
@@ -146,14 +164,14 @@ class Types:
     @property
     def unique(self) -> Types:
         """Fields marked with unique are picked up by ORM integrations to setup
-        database column unique index for you. This marker doesn't have any effect
-        around transforming and validating. When database engine raises an
-        exception, jsonclasses's web framework integration will catch it and return
-        400 automatically.
+        database column unique index for you. This marker doesn't have any
+        effect around transforming and validating. When database engine raises
+        an exception, jsonclasses's web framework integration will catch it and
+        return 400 automatically.
 
         If you are implementing jsonclasses ORM integration, you should use
-        UniqueFieldException provided by jsonclasses.exceptions to keep consistency
-        with other jsonclasses integrations.
+        UniqueFieldException provided by jsonclasses.exceptions to keep
+        consistency with other jsonclasses integrations.
         """
         return Types(self, UniqueValidator())
 
@@ -172,15 +190,15 @@ class Types:
         return Types(self, LinkToValidator())
 
     def linkedby(self, foreign_key: str) -> Types:
-        """In a database relationship, fields marked with linkedby find reference
-        from the destination table.
+        """In a database relationship, fields marked with linkedby find
+        reference from the destination table.
         """
         return Types(self, LinkedByValidator(foreign_key))
 
     def linkedthru(self, foreign_key: str) -> Types:
         """In a database relationship, fields marked with linkedthru save
-        relationships to a designated association table and find references through
-        it.
+        relationships to a designated association table and find references
+        through it.
         """
         return Types(self, LinkedThruValidator(foreign_key))
 
@@ -191,15 +209,15 @@ class Types:
         return Types(self, LinkedInValidator(cls))
 
     def referrer(self, referrer_key: str) -> Types:
-        """In a many to many database relationship, fields marked with referrer has
-        a provided custom key name in the association table.
+        """In a many to many database relationship, fields marked with referrer
+        has a provided custom key name in the association table.
         """
         return Types(self, ReferrerValidator(referrer_key))
 
     def referee(self, referee_key: str) -> Types:
         """In a many to many database relationship, fields marked with referee
-        reference the other side of the relationship with this provided custom key
-        name.
+        reference the other side of the relationship with this provided custom
+        key name.
         """
         return Types(self, RefereeValidator(referee_key))
 
@@ -216,14 +234,14 @@ class Types:
         return Types(self, MatchValidator(pattern))
 
     def oneof(self, str_list: list[Str]) -> Types:
-        """This is the enum equivalent for jsonclasses. Values in the provided list
-        are considered valid values.
+        """This is the enum equivalent for jsonclasses. Values in the provided
+        list are considered valid values.
         """
         return Types(self, OneOfValidator(str_list))
 
     def minlength(self, length: int) -> Types:
-        """Values at fields marked with minlength should have a length which is not
-        less than length.
+        """Values at fields marked with minlength should have a length which is
+        not less than length.
 
         Args:
           length (int): The minimum length required for the value.
@@ -234,8 +252,8 @@ class Types:
         return Types(self, MinlengthValidator(length))
 
     def maxlength(self, length: int) -> Types:
-        """Values at fields marked with maxlength should have a length which is not
-        greater than length.
+        """Values at fields marked with maxlength should have a length which is
+        not greater than length.
 
         Args:
           length (int): The minimum length required for the value.
@@ -246,9 +264,9 @@ class Types:
         return Types(self, MaxlengthValidator(length))
 
     def length(self, minlength: int, maxlength: Optional[int] = None) -> Types:
-        """Fields marked with length should have a length which is between the two
-        arguments. If only one argument is provided, the value length should be
-        exactly that length.
+        """Fields marked with length should have a length which is between the
+        two arguments. If only one argument is provided, the value length
+        should be exactly that length.
 
         Args:
           minlength (int): The minimum length required for the value.
@@ -267,7 +285,8 @@ class Types:
 
     @property
     def float(self) -> Types:
-        """Fields marked with float should be float type. This is a type marker.
+        """Fields marked with float should be float type. This is a type
+        marker.
         """
         return Types(self, FloatValidator())
 
@@ -278,14 +297,14 @@ class Types:
         return Types(self, MinValidator(value))
 
     def max(self, value: Float) -> Types:
-        """Fields marked with max are tested again this value. Values greater than
-        the argument value are considered invalid.
+        """Fields marked with max are tested again this value. Values greater
+        than the argument value are considered invalid.
         """
         return Types(self, MaxValidator(value))
 
     def range(self, min_value: Float, max_value: Float) -> Types:
-        """Fields marked with range are tested again argument values. Only values
-        between the arguments range are considered valid.
+        """Fields marked with range are tested again argument values. Only
+        values between the arguments range are considered valid.
         """
         return Types(self, RangeValidator(min_value, max_value))
 
@@ -320,21 +339,74 @@ class Types:
         """
         return Types(self, DatetimeValidator())
 
+    def enum(self, enum_class: Union[type, str]) -> Types:
+        """Fields marked with enum should be enum value of provided enum type.
+        This is a type marker.
+        """
+        return Types(self, EnumValidator(enum_class))
+
+    @property
+    def inputall(self) -> Types:
+        """Inputall makes enum field to accept all kinds of acceptable enum
+        values in any forms.
+        """
+        return Types(self, InputAllValidator())
+
+    @property
+    def inputlname(self) -> Types:
+        """Inputlname makes enum field to accept enum's lowercase name as
+        input.
+        """
+        return Types(self, InputLnameValidator())
+
+    @property
+    def inputname(self) -> Types:
+        """Inputlname makes enum field to accept enum's uppercase name as
+        input.
+        """
+        return Types(self, InputNameValidator())
+
+    @property
+    def inputvalue(self) -> Types:
+        """Inputlname makes enum field to accept enum's value as input.
+        """
+        return Types(self, InputValueValidator())
+
+    @property
+    def outputlname(self) -> Types:
+        """Outputlname makes enum field to output lowercase name as display
+        value.
+        """
+        return Types(self, OutputLnameValidator())
+
+    @property
+    def outputname(self) -> Types:
+        """Outputname makes enum field to output uppercase name as display
+        value.
+        """
+        return Types(self, OutputNameValidator())
+
+    @property
+    def outputvalue(self) -> Types:
+        """Outputvalue makes enum field to output value as display value.
+        """
+        return Types(self, OutputValueValidator())
+
     def listof(self, item_types: Any) -> Types:
-        """Fields marked with listof should be a list of the given type. This is a
-        type marker.
+        """Fields marked with listof should be a list of the given type. This
+        is a type marker.
         """
         return Types(self, ListOfValidator(item_types))
 
     def dictof(self, item_types: Any) -> Types:
-        """Fields marked with listof should be a str keyed dict of the given type.
-        This is a type marker.
+        """Fields marked with listof should be a str keyed dict of the given
+        type. This is a type marker.
         """
         return Types(self, DictOfValidator(item_types))
 
     def shape(self, item_types_map: dict[Str, Any]) -> Types:
-        """Fields marked with shape are objects shaped with given shape. This is a
-        type marker.
+        """Fields marked with shape are objects shaped with given shape. This
+        is a type marker.
         """
         return Types(self, ShapeValidator(item_types_map))
 
@@ -356,8 +428,7 @@ class Types:
 
     @property
     def required(self) -> Types:
-        """Fields marked with required are invalid when value is not presented aka
-        None.
+        """Fields marked with required are invalid when value is None.
 
         Returns:
           Types: A new types chained with this marker.
@@ -384,29 +455,64 @@ class Types:
         """
         return Types(self, PresentValidator())
 
+    def presentwith(self, referring_key: str) -> Types:
+        """Fields marked with presentwith validator are forced presented if
+        referring field is present. If referring field has None value, this
+        field's value is optional. If referring field has non None value, value
+        of this field is required.
+        """
+        return Types(self, PresentWithValidator(referring_key))
+
+    def presentwithout(self, referring_keys: Union[str, list[str]]) -> Types:
+        """Fields marked with presentwithout validator are forced presented if
+        referring field is not present. If referring field has None value, this
+        field's value should be present. If referring field has non None value,
+        value of this field is not forced to be present.
+        """
+        return Types(self, PresentWithoutValidator(referring_keys))
+
     def validate(self, validate_callable) -> Types:
-        """The validate field mark takes a validator callable as its sole argument.
-        Use this to define custom field value validations.
+        """The validate field mark takes a validator callable as its sole
+        argument. Use this to define custom field value validations.
 
         Args:
-          validate_callable (Callable): The validate callable tasks 3 arguments,
-          value, key_path, and root. Returning None means the value is valid, while
-          returning a str message means the validation failed.
+            validate_callable (Callable): The validate callable tasks up to 4
+            arguments, which are value, key path, root and context. Returning
+            None means the value is valid, while returning a str message means
+            validation failed.
 
         Returns:
-          Types: A new types chained with this marker.
+            Types: A new types chained with this marker.
         """
         return Types(self, ValidateValidator(validate_callable))
 
+    def compare(self, compare_callable: Callable) -> Types:
+        """The compare field mark takes a validator callable as its sole
+        argument. If value of compared fields are changed, this validator is
+        called with 2 to 5 arguments.
+
+        Args:
+            compare_callable (Callable): The compare callable. Arg 1 is the old
+            value, arg 2 is the new value, arg 3 is key path, arg 4 is the
+            object, arg 5 is the context. Returning None means the value is
+            valid, while returning a str message means validation failed.
+
+        Returns:
+            Types: A new types chained with this marker.
+        """
+        return Types(self,
+                     ResetValidator(),
+                     CompareValidator(compare_callable))
+
     # transformers
 
     def default(self, value: Any) -> Types:
-        """During initialization, if values of fields with default are not provided.
-        The default value is used instead of leaving blank.
+        """During initialization, if values of fields with default are not
+        provided. The default value is used instead of leaving blank.
 
         Args:
-          value (any): The default value of this field. If the value is callable,
-          it's return value is used.
+          value (any): The default value of this field. If the value is
+          callable, it's return value is used.
 
         Returns:
           Types: A new types chained with this marker.
@@ -423,7 +529,7 @@ class Types:
         Returns:
           Types: A new types chained with this marker.
         """
-        return Types(self, TruncateValidator(max_length))
+        return Types(self, EagerValidator(), TruncateValidator(max_length))
 
     @property
     def trim(self) -> Types:
@@ -433,7 +539,7 @@ class Types:
         Returns:
             Types: A new types chained with this marker.
         """
-        return Types(self, TrimValidator())
+        return Types(self, EagerValidator(), TrimValidator())
 
     def transform(self, transformer: Callable) -> Types:
         """This mark applies transfromer on the value. When value is None, the
@@ -460,7 +566,44 @@ class Types:
         Returns:
           Types: A new types chained with this marker.
         """
-        return Types(self, SetOnSaveValidator(setter))
+        return Types(self, PreserializeValidator(), SetOnSaveValidator(setter))
+
+    def onsave(self, callback: Callable) -> Types:
+        """Onsave inserts a callback into the validator chain. If save action
+        is triggered, the callback is called with the current value.
+
+        Args:
+            callback (Callable): This callback function takes one argument
+            which is the current value of the field.
+
+        Returns:
+            Types: A new types chained with this marker.
+        """
+        return Types(self, OnSaveValidator(callback))
+
+    def onupdate(self, callback: Callable) -> Types:
+        """Onupdate is a callback validator. If value updated when saving, this
+        callback is called with the current value or both values.
+
+        Args:
+            callback (Callable): A callable which takes arguments.
+
+        Returns:
+            Types: A new types chained with this marker.
+        """
+        return Types(self, ResetValidator(), OnUpdateValidator(callback))
+
+    def onwrite(self, callback: Callable) -> Types:
+        """Onwrite is a callback validator. Whenever a new value is being
+        serialized into the database, this is called.
+
+        Args:
+            callback (Callable): A callable which takes arguments.
+
+        Returns:
+            Types: A new types chained with this marker.
+        """
+        return Types(self, OnWriteValidator(callback))
 
     @property
     def nonnull(self) -> Types:
@@ -482,7 +625,7 @@ accessor annotation, validator annotation and transformer annotation, use types
 like this:
 
   @jsonclass
-  class MyObject(JSONObject):
+  class MyObject:
     my_field_one: bool = types.bool.readonly.required
     my_field_two: password = types.bool.writeonly.length(8, 16).transform(salt\
 ).required
