@@ -1,10 +1,10 @@
 """module for nonnull validator."""
 from .validator import Validator
-from ..fields import FieldDescription, Nullability
+from ..field_definition import FieldDefinition, Nullability
 
 
 class NonnullValidator(Validator):
     """A nonnull validator transforms None into empty library."""
 
-    def define(self, fdesc: FieldDescription) -> None:
+    def define(self, fdesc: FieldDefinition) -> None:
         fdesc.collection_nullability = Nullability.NONNULL
