@@ -1,10 +1,10 @@
 """module for readonly validator."""
-from ..fields import FieldDescription, WriteRule
+from ..field_definition import FieldDefinition, WriteRule
 from .validator import Validator
 
 
 class ReadonlyValidator(Validator):
     """Readonly validator marks a field to be readonly."""
 
-    def define(self, fdesc: FieldDescription) -> None:
+    def define(self, fdesc: FieldDefinition) -> None:
         fdesc.write_rule = WriteRule.NO_WRITE
