@@ -1,11 +1,11 @@
 """module for readwrite validator."""
-from ..fields import FieldDescription, WriteRule, ReadRule
+from ..field_definition import FieldDefinition, WriteRule, ReadRule
 from .validator import Validator
 
 
 class ReadwriteValidator(Validator):
     """Readwrite validator marks a field both readable and writable."""
 
-    def define(self, fdesc: FieldDescription) -> None:
+    def define(self, fdesc: FieldDefinition) -> None:
         fdesc.write_rule = WriteRule.UNLIMITED
         fdesc.read_rule = ReadRule.UNLIMITED
