@@ -1,5 +1,5 @@
 """module for referee validator."""
-from ..fields import FieldDescription
+from ..field_definition import FieldDefinition
 from .validator import Validator
 
 
@@ -9,5 +9,5 @@ class RefereeValidator(Validator):
     def __init__(self, referee_key: str) -> None:
         self.referee_key = referee_key
 
-    def define(self, fdesc: FieldDescription) -> None:
+    def define(self, fdesc: FieldDefinition) -> None:
         fdesc.join_table_referee_key = self.referee_key
